"""Custom logging configuration for Apache Airflow"""

import os
from copy import deepcopy
from airflow.utils.file import mkdirs
from airflow.config_templates.airflow_local_settings import (
    DEFAULT_DAG_PARSING_LOGGING_CONFIG,
)
from airflow.config_templates.airflow_local_settings import DEFAULT_LOGGING_CONFIG


DAG_PARSING_LOGGING_CONFIG = deepcopy(DEFAULT_DAG_PARSING_LOGGING_CONFIG)
LOGGING_CONFIG = deepcopy(DEFAULT_LOGGING_CONFIG)

LOGGING_CONFIG["loggers"]["airflow.processor"]["level"] = "WARNING"
DAG_PARSING_LOGGING_CONFIG["handlers"]["processor_manager"]["maxBytes"] = (
    50 * 2**20
)  # 50MB

if os.environ.get("CONFIG_PROCESSOR_MANAGER_LOGGER") == "True":
    LOGGING_CONFIG["handlers"].update(DAG_PARSING_LOGGING_CONFIG["handlers"])
    LOGGING_CONFIG["loggers"].update(DAG_PARSING_LOGGING_CONFIG["loggers"])

    # Manually create log directory for processor_manager handler as RotatingFileHandler
    # will only create file but not the directory.
    processor_manager_handler_config = DAG_PARSING_LOGGING_CONFIG["handlers"][
        "processor_manager"
    ]
    directory = os.path.dirname(processor_manager_handler_config["filename"])
    mkdirs(directory, 0o755)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['helloheart_airflow_utils', 'helloheart_airflow_utils.logging']

package_data = \
{'': ['*']}

install_requires = \
['apache-airflow<=1.10.12']

setup_kwargs = {
    'name': 'helloheart-airflow-utils',
    'version': '0.1.0',
    'description': 'Apache Airflow Utilities',
    'long_description': '# HelloHeart Airflow Utilities\n\nUseful utilities for Apache Airflow, courtesy of HelloHeart.\n\nIt supports Python 3.6 - 3.8.\n\n## Installation\n\n### Install latest release\nLatest release are uploaded to PyPi, install using pip:\n\n```bash\npip install helloheart-airflow-utils\n```\n\n### Install from source to use latest development version\nInstall latest development version, clone the repository and install using Poetry:\n\n```bash\ngit clone https://<helloheart-airflow-utils_repo_url>\ncd helloheart-airflow-utils\npoetry install\n```\n\n## Running the tests\n\n### Single Python version testing\nFor testing a single Python version, use pytest (after installing from source):\n\n```bash\npytest tests\n```\n\n### Multiple Python versions testing\nFor testing multiple Python versions, use tox:\n\n```bash\ntox\n```',
    'author': 'Ory Jonay',
    'author_email': 'ory.jonay@helloheart.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.2,<3.9',
}


setup(**setup_kwargs)
